@@ -43,6 +43,7 @@ class MachineState:
         self._assign_mode = False
         self._loop_limit = 10000
         self._cur_jac_ast = Ast("none")
+        self._write_candidate = None
         self.inform_hook()
 
     def inform_hook(self):
@@ -95,6 +96,11 @@ class MachineState:
         else:
             self.push(val)
 
+    def candidate_writethrough(self):
+        if self._write_candidate:
+            self._write_candidate.save()
+            self._write_candidate = None
+
     def perform_assignment(self, dest, src, jac_ast=None):
         if dest.check_assignable(jac_ast):
             dest.value = src.value
@@ -166,7 +172,7 @@ class MachineState:
         ret = JacSet()
         for i in edge_set.obj_list():
             for j in node_set.obj_list():
-                if i.jid in j.edge_ids:
+                if i.jid in j.smart_edge_list:
                     ret.add_obj(i)
                     break
         return ret
