@@ -1,4 +1,5 @@
 import io
+import os
 import pstats
 import cProfile
 import pdb
@@ -212,6 +213,17 @@ def perf_test_stop(perf_prof):
     return s
 
 
+def perf_test_to_b64(perf_prof, do_delete=True):
+    s = ""
+    fn = f"{id(perf_prof)}.prof"
+    if os.path.exists(fn):
+        with open(fn, "rb") as image_file:
+            s = base64.b64encode(image_file.read()).decode()
+        if do_delete:
+            os.remove(fn)
+    return s
+
+
 class TestCaseHelper:
     """Helper to pretty print test results"""
 
